@@ -46,8 +46,13 @@ LOG_TYPE_REGEX = Regex(
     r"|Fluentd\.Syslog5424|GCP\.AuditLog|GCP\.HTTPLoadBalancer|GitHub\.Audit|GitLab\.API|GitLab\.Audit|GitLab\.Exceptions"
     r"|GitLab\.Git|GitLab\.Integrations|GitLab\.Production|Gravitational\.TeleportAudit|GSuite\."
     r"ActivityEvent|GSuite\.Reports|Juniper\.Access|Juniper\.Audit|Juniper\.Firewall|Juniper\.MWS"
-    r"|Juniper\.Postgres|Juniper\.Security|Lacework\.AlertDetails|Lacework\.CloudCompliance|"
-    r"Lacework\.Events|Microsoft365\.Audit\.AzureActiveDirectory|Microsoft365\.Audit\.Exchange"
+    r"|Juniper\.Postgres|Juniper\.Security|Lacework\.AgentManagement|Lacework\.AlertDetails|Lacework\.AllFiles|"
+    r"Lacework\.Applications|Lacework\.ChangeFiles|Lacework\.CloudCompliance|Lacework\.CloudConfiguration|"
+    r"Lacework\.Cmdline|Lacework\.Connections|Lacework\.ContainerSummary|Lacework\.ContainerVulnDetails|"
+    r"Lacework\.DNSQuery|Lacework\.Events|Lacework\.HostVulnDetails|Lacework\.Image|Lacework\.Interfaces|"
+    r"Lacework\.InternalIPA|Lacework\.MachineDetails|Lacework\.MachineSummary|Lacework\.NewHashes|"
+    r"Lacework\.Package|Lacework\.PodSummary|Lacework\.ProcessSummary|Lacework\.UserDetails|Lacework\.UserLogin"
+    r"|Microsoft365\.Audit\.AzureActiveDirectory|Microsoft365\.Audit\.Exchange"
     r"|Microsoft365\.Audit\.General|Microsoft365\.Audit\.SharePoint|Microsoft365\.DLP\.All|"
     r"MicrosoftGraph\.SecurityAlert|"
     r"Nginx\.Access|Okta\.SystemLog|OneLogin\.Events|Osquery\.Batch|Osquery\.Differential|"
@@ -76,6 +81,14 @@ TYPE_SCHEMA = Schema(
     ignore_extra_keys=True,
 )
 
+MOCK_SCHEMA = Schema(
+    {
+        "objectName": str,
+        # best effort to detect str: because of the ruamel bool constructor, boolean strings are converted to bools
+        "returnValue": Or(str, bool),
+    }
+)
+
 DATA_MODEL_SCHEMA = Schema(
     {
         "AnalysisType": Or("datamodel"),
@@ -144,7 +157,7 @@ POLICY_SCHEMA = Schema(
                 ): str,  # Not needed anymore, optional for backwards compatibility
                 "ExpectedResult": bool,
                 "Resource": object,
-                Optional("Mocks"): object,
+                Optional("Mocks"): [MOCK_SCHEMA],
             }
         ],
     },
@@ -178,7 +191,7 @@ RULE_SCHEMA = Schema(
                 ): str,  # Not needed anymore, optional for backwards compatibility
                 "ExpectedResult": bool,
                 "Log": object,
-                Optional("Mocks"): object,
+                Optional("Mocks"): [MOCK_SCHEMA],
             }
         ],
     },
